<?php
/*
 * $Id: main.php,v 1.4.2.1.2.8 2004/01/01 18:20:00 mdean Exp $
 *
 * Double Choco Latte - Source Configuration Management System
 * Copyright (C) 1999  Michael L. Dean & Tim R. Norman
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Select License Info from the Help menu to view the terms and conditions of this license.
 */

include_once('login.php');

$g_oSec = CreateObject('dcl.boSecurity');

$g_oPage = GetPageObject();
$g_oPage->StartPage();

if (IsSet($menuAction) && $menuAction != 'clearScreen')
{
	if ($g_oSec->ValidateMenuAction() == true)
	{
		Invoke($menuAction);
	}
	else
	{
		commonHeader();
		PrintPermissionDenied();
	}
}
else
{
	commonHeader();
}

$g_oPage->EndPage();
?>
